<?php
/**
 * 银联条码支付前置平台 商户、微信/支付宝支付基础API
 * @category   api
 * Created by PhpStorm.
 * User: roc
 * Date: 2019/11/06
 * Time: 11:56
 */

namespace kwy\union\up;

use kwy\util\http\CurlHttp;

class UnionApi{

    /**
     * @var CurlHttp
     */
    private $httpClient;

    /**
     * 银联前置网关
     * @var string
     */
    protected $host = "";

    /**
     * 授权交易的服务商机构代码，商户授权给服务商交易的情况下必填，签名使用服务商的密钥
     * @var string
     */
    protected $sign_agentno = "";

    /**
     * 连锁商户号
     * @var string
     */
    protected $groupno = "";

    /**
     * 秘钥（可以是商户秘钥，服务商模式下填写服务商秘钥，连锁模式下用连锁商户的密钥）
     * @var
     */
    protected $key;

    /**
     * 设置授权交易的服务商机构代码
     * @author roc
     * @datetime:2019/12/12 10:55
     * @param $sign_agentno
     * @return $this
     */
    public function setAgentNo($sign_agentno){
        $this->sign_agentno = $sign_agentno;
        return $this;
    }

    /**
     * 获取授权交易的服务商机构代码
     * @author roc
     * @return string
     */
    public function getAgentNo(){
        return $this->sign_agentno;
    }

    /**
     * 设置连锁商户号（连锁商户为其下门店发交易的情况必填，签名使用连锁商户的密钥）
     * @author roc
     * @datetime:2019/12/12 11:03
     * @param string $groupNo
     * @return $this
     */
    public function setGroupNo($groupNo){
        $this->groupno = $groupNo;
        return $this;
    }

    /**
     * 获取连锁商户号
     * @author roc
     * @return string
     */
    public function getGroupNo(){
        return $this->groupno;
    }

    /**
     * 设置密钥（服务商模式下，使用服务商秘钥；连锁模式下，使用连锁商户的密钥）
     * @author roc
     * @param string $key
     * @return $this
     */
    public function setKey($key){
        $this->key = $key;
        return $this;
    }

    /**
     * 获取密钥（服务商模式下，获取的是服务商秘钥；连锁模式下；获取的是连锁商户的密钥）
     * @author roc
     * @return string
     */
    public function getKey(){
        return $this->key;
    }

    /**
     * 设置银联请求域名地址
     * @author roc
     * @datetime:2019/12/12 11:28
     * @param $host
     * @return $this
     */
    public function setHost($host){
        $this->host = $host;
        return $this;
    }

    /**
     * 获取银联请求域名地址
     * @author roc
     * @return string
     */
    public function getHost(){
        return $this->host;
    }

    /**
     * 获取随机字符串
     * @author roc
     * @datetime:2019/12/12 11:18
     * @param int $len 随机字符串位数
     * @return string
     */
    protected function getNonceStr($len=32){
        $chars = "abcdefghijklmnopqrstuvwxyz0123456789";
        $str ="";
        for ( $i = 0; $i < $len; $i++ )  {
            $str.= substr($chars, mt_rand(0, strlen($chars)-1), 1);
        }
        return $str;
    }

    /**
     * 数组转xml数据
     * @author roc
     * @datetime:2019/12/12 11:25
     * @param $arr
     * @param bool $c_data
     * @return string
     */
    protected function arrayToXml($arr,$c_data=false){
        $xml='<xml>';
        foreach ($arr as $k=>$v){
            if ($c_data){
                $xml.='<'.$k.'><![CDATA['.$v.']]></'.$k.'>'."\n";
            }else {
                $xml.='<'.$k.'>'.$v.'</'.$k.'>'."\n";
            }
        }
        $xml.='</xml>';
        return $xml;
    }

    /**
     * xml数据转数组
     * @author roc
     * @datetime:2019/12/12 11:25
     * @param $xml
     * @return mixed
     */
    public function xmlToArray($xml){
        $arr=json_decode(json_encode(simplexml_load_string($xml,null,LIBXML_NOCDATA)),true);
        return $arr;
    }

    /**
     * 获取签名
     * @author roc
     * @datetime:2019/12/12 11:20
     * @param $params
     * @return string
     * @throws \Exception
     */
    protected function getSign($params){
        if(empty($this->key)) throw new \Exception("秘钥未设置");
        ksort($params);
        $str='';
        foreach ($params as $k=>$v){
            if(empty($v) || $v == "0" || $v == ""){
                continue;
            }
            $str.=$k.'='.$v.'&';
        }
        $str=rtrim($str,'&');

        $str.='&key'.'='.$this->key;
        $sign=strtoupper(md5($str));
        return $sign;

    }

    /**
     * 签名校验
     * @param array $params
     * @return boolean
     * @throws \Exception
     */
    public function checkSign($params){
        if(empty($this->key)) throw new \Exception("秘钥未设置");
        $post_sign=$params['sign'];
        unset($params['sign']);
        ksort($params);
        $str='';
        foreach ($params as $k=>$v){
            $str.=$k.'='.$v.'&';
        }
        $str=rtrim($str,'&');

        $str.='&key='.$this->key;
        $sign=strtoupper(md5($str));
        if (strcmp($sign, $post_sign)!==0){
            return false;
        }else {
            return true;
        }
    }

    /**
     * 设置代理
     * @author roc
     * @datetime:2019/12/8 14:37
     * @param $proxy
     * @return $this
     */
    public function setProxy($proxy){
        $this->getHttpClient()->setProxy($proxy);
        return $this;
    }

    /**
     * 获取http请求客户端
     * @author roc
     * @return CurlHttp
     */
    public function getHttpClient(){
        if (empty($this->httpClient)){
            $this->httpClient = new CurlHttp();
            //$this->httpClient->setProxy('127.0.0.1:8888');
            $this->httpClient->setContentType('application/json');
        }
        return $this->httpClient;
    }
}