<?php
namespace kwy\union\up\pay;


class UnionPayResult{

    private $data = null;

    /**
     * 正常支付成功结果api数据
     * @param array $data
     */
    public function __construct($data){
        $this->data=$data;
    }

	/**
	 * 获取订单金额,单位：分
     * @author roc
     * @datetime:2019/12/12 18:20
     * @return float
     */
	public function getPrice(){
	    return $this->data["total_fee"];
	}

    /**
     * 获取上游通道优惠金额
     * @author roc
     * @datetime:2019/12/12 18:23
     * @return string
     */
    public function getDiscountPrice()
    {
        return "0";
    }

	/**
	 * 获取买家支付宝账号【支付宝】
     * @author roc
     * @datetime:2019/12/12 18:23
     * @return mixed|string
     */
	public function getAliLoginId(){
		return empty($this->data['buyer_logon_id'])?"支付宝用户":$this->data['buyer_logon_id'];
	}

    /**
     * 获取买家支付宝用户ID【支付宝】
     * @author roc
     * @datetime:2019/12/12 18:23
     * @return mixed|string
     */
    public function getAliUserId(){
        return empty($this->data['buyer_user_id'])?"":$this->data['buyer_user_id'];
    }

    /**
     * 获取商户appid
     * @author roc
     * @datetime:2019/12/12 18:28
     * @return mixed|string
     */
    public function getAppId(){
        return empty($this->data["appid"]) ? "" : $this->data["appid"];
    }

    /**
     * 用户在受理商户 appid 下的唯一标识 openid
     * @author roc
     * @datetime:2019/12/12 18:30
     * @return string
     */
    public function getOpenid(){
        return empty($this->data['openid']) ? '' : $this->data['openid'].'';
    }

    /**
     * 获取子商户appid
     * @author roc
     * @datetime:2019/12/12 18:28
     * @return mixed|string
     */
	public function getSubAppId(){
		return empty($this->data["sub_appid"]) ? "" : $this->data["sub_appid"];
	}

    /**
     * 获取用户在子商户appid下的唯一标识sub_openid
     * @author roc
     * @datetime:2019/12/12 18:30
     * @return string
     */
	public function getSubOpenid(){
        return empty($this->data['sub_openid']) ? '' : $this->data['sub_openid'].'';
	}
	
	/**
	 * 获取支付方式
     * @author roc
     * @datetime:2019/12/12 18:40
     * @return string
     * @throws \Exception
     */
	public function getPayMethod(){
	    if(empty($this->data["trade_type"])){
	        throw new \Exception("获取不到该支付方式，请联系技术");
        }
        /**
         * pay.weixin.micropay——微信被扫支付
         *              pay.alipay.micropay——支付宝被扫支付
         *              pay.unionpay.micropay——银联被扫支付
         *              pay.alipay.jspay——支付宝
         *              pay.weixin.jspay——微信
         *              pay.unionpay.native——银联
         */
        if(strpos($this->data["trade_type"],"weixin") !== false){
            return "微信支付";
        }elseif(strpos($this->data["trade_type"],"alipay") !== false){
            return "支付宝支付";
        }elseif(strpos($this->data["trade_type"],"unionpay") !== false){
            return "银联支付";
        }else {
			throw new \Exception("获取不到该支付方式，请联系技术");
		}
	}

	public function getOutNo(){
	    $out_no = empty($this->data["out_trade_no"]) ? "" : $this->data["out_trade_no"];
	    return $out_no;
    }

	/**
	 * 获取微信、支付宝订单号
     * @author roc
     * @datetime:2019/12/12 18:41
     * @return mixed|string
     */
	public function getFirstNo(){
        $out_transaction_id = empty($this->data["out_transaction_id"]) ? "" : $this->data["out_transaction_id"];
		return $out_transaction_id;
	}
	
	/**
	 * 获取银联平台订单号
     * @author roc
     * @datetime:2019/12/12 18:42
     * @return mixed|string
     */
	public function getThirdNo(){
        $transaction_id = empty($this->data["transaction_id"]) ? "" : $this->data["transaction_id"];
        return $transaction_id;
	}
	
	/**
	 * 获取用户支付方式（招商银行、财付通、还是中信银行）类型
     * @author roc
     * @datetime:2019/12/12 18:44
     * @return mixed|string
     */
	public function getBankType(){
		return empty($this->data['bank_type']) ? '' : $this->data['bank_type'];
	}
	
	/**
	 * 获取发起支付类型（js支付还是micropay）
     * @author roc
     * @datetime:2019/12/12 18:44
     * @return string
     */
	public function getTradeType(){
        /**
         * pay.weixin.micropay——微信被扫支付
         *              pay.alipay.micropay——支付宝被扫支付
         *              pay.unionpay.micropay——银联被扫支付
         *              pay.alipay.jspay——支付宝
         *              pay.weixin.jspay——微信
         *              pay.unionpay.native——银联
         */
        if(strpos($this->data['trade_type'],'micropay') !== false){
            return 'micropay';
        }else{
            return 'jspay';
        }
	}

	
	/**
	 * 获取支付状态
     * @author roc
     * @datetime:2019/12/12 18:48
     * @return string
     */
	public function getPayStatus(){
        if ($this->data['result_code']=='0'&&$this->data['pay_result']=='0'){
            return '已支付';
        }
        if ($this->data['err_code']=='USERPAYING'||$this->data['trade_state']=='USERPAYING'){
            return '支付中';
        }
        switch ($this->data["trade_state"]){
            case "SUCCESS":
                return '已支付';
            case "REFUND":
                return '退款成功';
            case "NOTPAY":
                return '支付中';
            case "CLOSED":
                return '订单关闭';
            case "REVOKED":
                return '订单撤销';
            case "REVERSE":
                return '订单撤销';
            case "USERPAYING":
                return '支付中';
            case "PAYERROR":
                return '支付失败';
            default:
                return '支付中';
        }
	}

    /**
     * 获取订单结束时间
     * @author roc
     * @datetime:2019/12/12 18:50
     * @return false|string
     */
	public function getTimeEnd(){
        if(!empty($this->data['time_end'])){
            return date('Y-m-d H:i:s',strtotime($this->data['time_end']));
        }
        return date('Y-m-d H:i:s');
    }
}